Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(435)

Unified Diff: media/filters/source_buffer_stream.h

Issue 1637213002: Revert of MSE: Relax the 'media segment must begin with keyframe' requirement (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/filters/media_source_state.cc ('k') | media/filters/source_buffer_stream.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/filters/source_buffer_stream.h
diff --git a/media/filters/source_buffer_stream.h b/media/filters/source_buffer_stream.h
index e158ec11851d9cb4aaae090e6397d2a8de8fe04f..89215959b6d111b6aa63d4b616a1f798e33ae449 100644
--- a/media/filters/source_buffer_stream.h
+++ b/media/filters/source_buffer_stream.h
@@ -68,11 +68,11 @@
~SourceBufferStream();
// Signals that the next buffers appended are part of a new coded frame group
// starting at |coded_frame_group_start_time|.
// TODO(acolwell/wolenetz): This should be changed to a presentation
// timestamp. See http://crbug.com/402502
- void OnStartOfCodedFrameGroup(DecodeTimestamp coded_frame_group_start_time);
+ void OnNewMediaSegment(DecodeTimestamp media_segment_start_time);
// Add the |buffers| to the SourceBufferStream. Buffers within the queue are
// expected to be in order, but multiple calls to Append() may add buffers out
@@ -397,15 +397,14 @@
// emitted buffer emptied |track_buffer_|.
bool just_exhausted_track_buffer_ = false;
- // The start time of the current coded frame group being appended.
- DecodeTimestamp coded_frame_group_start_time_;
+ // The start time of the current media segment being appended.
+ DecodeTimestamp media_segment_start_time_;
// Points to the range containing the current media segment being appended.
RangeList::iterator range_for_next_append_;
- // True when the next call to Append() begins a new coded frame group.
- // TODO(wolenetz): Simplify by passing this flag into Append().
- bool new_coded_frame_group_ = false;
+ // True when the next call to Append() begins a new media segment.
+ bool new_media_segment_ = false;
// The timestamp of the last buffer appended to the media segment, set to
// kNoDecodeTimestamp() if the beginning of the segment.
« no previous file with comments | « media/filters/media_source_state.cc ('k') | media/filters/source_buffer_stream.cc » ('j') | no next file with comments »
@@ -68,11 +68,11 @@
~SourceBufferStream();
- // Signals that the next buffers appended are part of a new coded frame group
- // starting at |coded_frame_group_start_time|.
+ // Signals that the next buffers appended are part of a new media segment
+ // starting at |media_segment_start_time|.
// TODO(acolwell/wolenetz): This should be changed to a presentation
// timestamp. See http://crbug.com/402502

Powered by Google App Engine
This is Rietveld 408576698